/**
 * Copyright (c) 2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api;

import java.util.logging.Logger;

import org.ow2.petals.jmx.api.api.exception.LoggerServiceErrorException;

/**
 * Interface of the JMX Logger service.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface LoggerServiceClient {

    /**
     * Name of the associated MBean
     */
    public static final String LOGGER_SERVICE_MBEAN_NAME = "PetalsLogger";

    /**
     * Set level value for a specified logger
     * 
     * @param logger
     *            The logger name, where the value should be assigned. 
     * @param level
     *            The <String> value of the log level that must be set.
     * @return
     * @throws <LoggerServiceErrorException> if an error occurs while performing
     *         the action
     */
    public void setLoggerLevel(final String logger, final String level)
            throws LoggerServiceErrorException;

    /**
     * Get level value for a specified logger
     * 
     * @param logger
     *            The logger name, where the value should be assigned.
     * @return
     * @throws <LoggerServiceErrorException> if an error occurs while performing
     *         the action
     */
    public String getLoggerLevel(final String logger) throws LoggerServiceErrorException;

    /**
     * This method allows to retrieve all levels.
     * 
     * @return <String[]> retrieve JDK logging <Level> and specific Petals
     *         logging <Level>.
     */
    public String[] getLevels() throws LoggerServiceErrorException;
    
    /**
     * This method allows to retrieve all loggers.
     * 
     * @return The name (index 0) and level (index 1) of all the {@link Logger}.
     */
    public String[][] getLoggers() throws LoggerServiceErrorException;
}
